@@ -5,6 +5,7 @@
  */
 
 #include "version.h"
+#include "config.h"
 #include "abi.h"
 #include "osutils.h"
 #include <unistd.h>
@@ -45,7 +46,7 @@ bool scan_abi(hwNode & system)
 
   popd();
 
-  system.describeCapability("vsyscall32", "32-bit processes");
-  system.describeCapability("vsyscall64", "64-bit processes");
+  system.describeCapability("vsyscall32", _("32-bit processes"));
+  system.describeCapability("vsyscall64", _("64-bit processes"));
   return true;
 }
