@@ -11,7 +11,7 @@
 
 //#include <linux/fs.h>
 
-__ID("@(#) $Id: disk.cc 2336 2010-10-05 09:34:27Z lyonel $");
+__ID("@(#) $Id: disk.cc 2433 2012-01-10 22:01:30Z lyonel $");
 
 #ifndef BLKROGET
 #define BLKROGET   _IO(0x12,94)                   /* get read-only status (0 = read_write) */
@@ -25,12 +25,16 @@ __ID("@(#) $Id: disk.cc 2336 2010-10-05 09:34:27Z lyonel $");
 #ifndef BLKSSZGET
 #define BLKSSZGET  _IO(0x12,104)                  /* get block device sector size */
 #endif
+#ifndef BLKPBSZGET
+#define BLKPBSZGET _IO(0x12,123)
+#endif
 
 bool scan_disk(hwNode & n)
 {
   long size = 0;
   unsigned long long bytes = 0;
   int sectsize = 0;
+  int physsectsize = 0;
 
   if (n.getLogicalName() == "")
     return false;
@@ -40,6 +44,11 @@ bool scan_disk(hwNode & n)
   if (fd < 0)
     return false;
 
+  if (ioctl(fd, BLKPBSZGET, &physsectsize) != 0)
+    physsectsize = 0;
+  if(physsectsize)
+    n.setConfig("sectorsize", physsectsize);
+
   if (n.getSize() == 0)
   {
     if(ioctl(fd, BLKGETSIZE64, &bytes) == 0)
