@@ -20,7 +20,7 @@
 #include <linux/kdev_t.h>
 #endif
 
-__ID("@(#) $Id: osutils.cc 2336 2010-10-05 09:34:27Z lyonel $");
+__ID("@(#) $Id: osutils.cc 2433 2012-01-10 22:01:30Z lyonel $");
 
 using namespace std;
 
@@ -431,9 +431,7 @@ string escape(const string & s)
     if (s[i] == 0x9
         || s[i] == 0xA
         || s[i] == 0xD
-        || (s[i] >= 0x20 && s[i] <= 0xD7FF)
-        || (s[i] >= 0xE000 && s[i] <= 0xFFFD)
-        || (s[i] >= 0x10000 && s[i] <= 0x10FFFF))
+        || s[i] >= 0x20)
       switch (s[i])
       {
         case '<':
@@ -583,7 +581,7 @@ int open_dev(dev_t dev, const string & name)
       snprintf(fn, sizeof(fn), "%s/lshw-%d", *p, getpid());
     else
       snprintf(fn, sizeof(fn), "%s", name.c_str());
-    if ((mknod(fn, (S_IFCHR | S_IREAD), dev) == 0) || (errno = EEXIST))
+    if ((mknod(fn, (S_IFCHR | S_IREAD), dev) == 0) || (errno == EEXIST))
     {
       fd = open(fn, O_RDONLY);
       if(name=="") unlink(fn);
@@ -626,10 +624,10 @@ string utf8(wchar_t c)
   return result;
 }
 
-string utf8(uint16_t * s, size_t length, bool forcelittleendian)
+string utf8(uint16_t * s, ssize_t length, bool forcelittleendian)
 {
   string result = "";
-  size_t i;
+  ssize_t i;
 
   for(i=0; (length<0) || (i<length); i++)
     if(s[i])
